@@ -49,6 +49,16 @@ pqxx::result &pqxx::result::operator=(PGresult *Other)
 }
 
 
+void pqxx::result::swap(pqxx::result &other) throw ()
+{
+  int *const refcount = m_Refcount;
+  PGresult *const res = m_Result;
+  m_Refcount = other.m_Refcount;
+  m_Result = other.m_Result;
+  other.m_Refcount = refcount;
+  other.m_Result = res;
+}
+
 
 const pqxx::result::tuple pqxx::result::at(pqxx::result::size_type i) const
   throw (out_of_range)
@@ -101,7 +111,7 @@ string pqxx::result::StatusError() const
   default:
     throw logic_error("libpqxx internal error: "
 		      "pqxx::result: Unrecognized response code " +
-		      ToString(int(PQresultStatus(m_Result))));
+		      to_string(int(PQresultStatus(m_Result))));
   }
   return Err;
 }
@@ -213,7 +223,7 @@ pqxx::result::column_name(pqxx::result::tuple::size_type Number) const
 {
   const char *const N = PQfname(m_Result, Number);
   if (!N) 
-    throw out_of_range("Invalid column number: " + ToString(Number));
+    throw out_of_range("Invalid column number: " + to_string(Number));
 
   return N;
 }
