@@ -34,7 +34,7 @@ int main()
       // Dump tuple number and column 0 value to cout.  Read the value using
       // as(), which converts the field to the same type as the default value 
       // you give it (or returns the default value if the field is null).
-      cout << '\t' << ToString(c.num()) << '\t' << c[0].as(string()) << endl;
+      cout << '\t' << to_string(c.num()) << '\t' << c[0].as(string()) << endl;
     }
 
     // Tell the transaction that it has been successful.  This is not really
