@@ -25,7 +25,7 @@ using namespace pqxx;
 // It is assumed to consist of an integer key called year, and a string.
 namespace
 {
-int BoringYear = 1977;
+const unsigned long BoringYear = 1977;
 
 } // namespace
 
@@ -43,10 +43,10 @@ int main(int argc, char *argv[])
     // Verify our start condition before beginning: there must not be a 1977
     // record already.
     result R( T1.exec(("SELECT * FROM " + Table + " "
-	               "WHERE year=" + ToString(BoringYear)).c_str()) );
+	               "WHERE year=" + to_string(BoringYear)).c_str()) );
     if (R.size() != 0)
       throw runtime_error("There is already a record for " + 
-	                  ToString(BoringYear) + ". "
+	                  to_string(BoringYear) + ". "
 		          "Can't run test.");
 
     // (Not needed, but verify that clear() works on empty containers)
@@ -57,7 +57,7 @@ int main(int argc, char *argv[])
     // OK.  Having laid that worry to rest, add a record for 1977.
     T1.exec(("INSERT INTO " + Table + " VALUES"
              "(" +
-	     ToString(BoringYear) + ","
+	     to_string(BoringYear) + ","
 	     "'Yawn'"
 	     ")").c_str());
 
@@ -69,11 +69,11 @@ int main(int argc, char *argv[])
     // Verify that our record was added, despite the Abort()
     nontransaction T2(C, "T2");
     R = T2.exec(("SELECT * FROM " + Table + " "
-		 "WHERE year=" + ToString(BoringYear)).c_str());
+		 "WHERE year=" + to_string(BoringYear)).c_str());
     if (R.size() != 1)
       throw runtime_error("Expected to find 1 record for " + 
-		          ToString(BoringYear) + ", found " +
-			  ToString(R.size()) + ". "
+		          to_string(BoringYear) + ", found " +
+			  to_string(R.size()) + ". "
 			  "This could be a bug in libpqxx, "
 			  "or something else modified the table.");
 
@@ -86,7 +86,7 @@ int main(int argc, char *argv[])
 
     // Now remove our record again
     T2.exec(("DELETE FROM " + Table + " "
-	     "WHERE year=" + ToString(BoringYear)).c_str());
+	     "WHERE year=" + to_string(BoringYear)).c_str());
 
     T2.commit();
 
@@ -94,10 +94,10 @@ int main(int argc, char *argv[])
     nontransaction T3(C, "T3");
 
     R = T3.exec(("SELECT * FROM " + Table + " "
-	         "WHERE year=" + ToString(BoringYear)).c_str());
+	         "WHERE year=" + to_string(BoringYear)).c_str());
     if (R.size() != 0)
-      throw runtime_error("Expected record for " + ToString(BoringYear) + " "
-		          "to be gone but found " + ToString(R.size()) + ". "
+      throw runtime_error("Expected record for " + to_string(BoringYear) + " "
+		          "to be gone but found " + to_string(R.size()) + ". "
 			  "This could be a bug in libpqxx, "
 			  "or something else modified the table.");
   }
