@@ -38,7 +38,7 @@ public:
       string N;
       c[0].to(N);
 
-      cout << '\t' << ToString(c.num()) << '\t' << N << endl;
+      cout << '\t' << to_string(c.num()) << '\t' << N << endl;
     }
   }
 };
